@@ -9,5 +9,5 @@ test_that("codalm works", {
     expect_true(is.matrix(B_est))
     expect_true(max(abs(B_row_sums - 1)) < 1e-8)
     expect_true(mean(B_est >= 0) == 1)
-    expect_true(all.equal(dim(B_est), c(2,3)))
+    expect_true(isTRUE(all.equal(dim(B_est), c(2,3))))
 })
