@@ -7,7 +7,7 @@ test_that("independence test works with sequential evaluation", {
     oplan <- plan("list")
     p <- codalm_indep_test(y, x)
     expect_true(p > .05)
-    expect_true(identical(plan("list"), oplan))
+    expect_true(isTRUE(all.equal(plan("list"), oplan)))
 })
 test_that("independence test works with multisession evaluation", {
     require(gtools)
@@ -17,6 +17,6 @@ test_that("independence test works with multisession evaluation", {
     y <- rdirichlet(100, rep(1,3))
     oplan <- plan("list")
     p <- codalm_indep_test(y, x, parallel = TRUE, strategy = 'multisession', ncpus = 2)
-    expect_true(identical(plan("list"), oplan))
+    expect_true(isTRUE(all.equal(plan("list"), oplan)))
 })
 
